@@ -24,7 +24,7 @@ sub execute {
         ) || 'rest';
     my $output;
     eval {
-        $output = encode_json( $c->stash->{$stash_key} );
+        $output = $self->serialize( $c->stash->{$stash_key} );
     };
     if ($@) {
         return $@;
@@ -33,4 +33,9 @@ sub execute {
     return 1;
 }
 
+sub serialize {
+    my $self = shift;
+    encode_json( shift );
+}
+
 1;
