@@ -24,7 +24,7 @@ sub execute {
         ) || 'rest';
     my $output;
     eval {
-        $output = Dump($c->stash->{$stash_key});
+        $output = $self->serialize($c->stash->{$stash_key});
     };
     if ($@) {
         return $@;
@@ -33,4 +33,10 @@ sub execute {
     return 1;
 }
 
+sub serialize {
+    my $self = shift;
+    my $data = shift;
+    Dump($data);
+}
+
 1;
